@@ -1,6 +1,6 @@
 from typing import Any, List
 
-from baseten_scaffolding.constants import SKLEARN, PYTORCH, TENSORFLOW, CUSTOM
+from baseten_scaffolding.constants import SKLEARN, PYTORCH, TENSORFLOW, CUSTOM, KERAS
 from baseten_scaffolding.definitions.base import ReadModelScaffoldDefinition
 from baseten_scaffolding.definitions.custom import CustomScaffoldDefinition
 from baseten_scaffolding.definitions.keras import KerasScaffoldDefinition
@@ -58,7 +58,7 @@ def scaffold(
             requirements_file=requirements_file,
             python_major_minor=python_major_minor,
         )
-    elif model_framework == TENSORFLOW:
+    elif model_framework == TENSORFLOW or model_framework == KERAS:
         return KerasScaffoldDefinition(
             model=model,
             model_type=model_type,
