@@ -61,7 +61,7 @@ class PyTorchModel(kfserving.KFModel):
         response = {}
         try:
             with torch.no_grad():
-                inputs = torch.tensor(request['instances'], dtype=self.model_dtype, device=self.device)
+                inputs = torch.tensor(request['inputs'], dtype=self.model_dtype, device=self.device)
                 response = {}
                 response['predictions'] = self.model(inputs).tolist()
                 return response
